@@ -1,18 +1,17 @@
 #![no_std]
 
 use core::ops::Range;
-use core::sync::atomic::{AtomicU64, Ordering};
 use core::time::Duration;
 
 pub struct Etime {
-    start: AtomicU64,
+    start: u64,
     clock: fn() -> u64,
 }
 impl Etime {
     const CLOCK_SOURCE: fn() -> u64 = clock_source::now;
     pub const fn new() -> Self {
         Self {
-            start: AtomicU64::new(0),
+            start: 0,
             clock: Self::CLOCK_SOURCE,
         }
     }
@@ -25,13 +24,13 @@ impl Etime {
     pub fn now(&self) -> u64 {
         (self.clock)()
     }
-    pub fn tic(&self) {
+    pub fn tic(&mut self) {
         let now = self.now();
-        self.start.store(now, Ordering::Relaxed);
+        self.start = now;
     }
-    pub fn toc(&self) -> Duration {
+    pub fn toc(&mut self) -> Duration {
         let now = self.now();
-        let start = self.start.load(Ordering::Relaxed);
+        let start = self.start;
         Duration::from_nanos(now - start)
     }
 }
