@@ -4,7 +4,7 @@ use std::thread;
 
 #[test]
 fn base() {
-    let etime = Etime::new();
+    let mut etime = Etime::new();
     etime.tic();
     thread::sleep(Duration::from_secs(1));
     let elapsed = etime.toc();
